@@ -5,25 +5,25 @@
 #define __M4RI_HAVE_MM_MALLOC		1
 #define __M4RI_HAVE_POSIX_MEMALIGN	1
 #define __M4RI_HAVE_SSE2		1
-#define __M4RI_HAVE_OPENMP		0
-#define __M4RI_CPU_L1_CACHE		65536
+#define __M4RI_HAVE_OPENMP		1
+#define __M4RI_CPU_L1_CACHE		32768
 #define __M4RI_CPU_L2_CACHE		524288
-#define __M4RI_CPU_L3_CACHE		8388608
+#define __M4RI_CPU_L3_CACHE		16777216
 #define __M4RI_DEBUG_DUMP		(0 || 0)
 #define __M4RI_DEBUG_MZD		0
 #define __M4RI_HAVE_LIBPNG              1
 
 #define __M4RI_CC                       "gcc"
-#define __M4RI_CFLAGS                   " -mmmx -msse -msse2 -msse3  -march=x86-64 -mtune=generic -O2 -pipe -fno-plt"
+#define __M4RI_CFLAGS                   " -mmmx -msse -msse2 -msse3 -fopenmp -march=x86-64 -mtune=generic -O2 -pipe -fno-plt"
 #define __M4RI_SIMD_CFLAGS              " -mmmx -msse -msse2 -msse3"
-#define __M4RI_OPENMP_CFLAGS            ""
+#define __M4RI_OPENMP_CFLAGS            "-fopenmp"
 
 // Helper macros.
 #define __M4RI_USE_MM_MALLOC		(__M4RI_HAVE_MM_MALLOC && __M4RI_HAVE_SSE2)
 #define __M4RI_USE_POSIX_MEMALIGN	(__M4RI_HAVE_POSIX_MEMALIGN && __M4RI_HAVE_SSE2)
 #define __M4RI_DD_QUIET			(0 && !0)
 
-#define __M4RI_ENABLE_MZD_CACHE         1
-#define __M4RI_ENABLE_MMC               1
+#define __M4RI_ENABLE_MZD_CACHE         0
+#define __M4RI_ENABLE_MMC               0
 
 #endif // M4RI_M4RI_CONFIG_H
